==> openGion6.2.6.0_dev.zip: uap/webapps/gf/db/firebird/sql/install/01_TABLE/GF85S.sql <==
/****************************************************************************/
/* GF85 ( 移行DB対応明細 )                                                  */
/*                                                                          */
/* Created : 2014/12/27 18:21:14                                            */
/****************************************************************************/
CREATE TABLE GF85 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TABLE_NAME   VARCHAR (   50 )                    NOT NULL            /*  30 ﾃｰﾌﾞﾙ名      */
 , CLM          VARCHAR (   30 )                    NOT NULL            /*  40 項目         */
 , SEQNO        INTEGER                 DEFAULT 0   NOT NULL            /*  50 表示順       */
 , NAME_JA      VARCHAR (  200 )                                        /*  60 名称         */
 , CLS_NAME     VARCHAR (   10 )                    NOT NULL            /*  70 DBｸﾗｽ        */
 , USE_LENGTH   VARCHAR (    9 )                                        /*  80 使用桁数     */
 , DATA_DEFAULT VARCHAR (  200 )                                        /*  90 初期値       */
 , NOT_NULL     VARCHAR (    1 )                                        /* 100 ﾉｯﾄﾇﾙ        */
 , KBCLM        VARCHAR (    1 )        DEFAULT '0' NOT NULL            /* 120 ｶﾗﾑ区分      */
 , BIKO         VARCHAR ( 2000 )                                        /* 130 備考         */
 , NOJUN        INTEGER                 DEFAULT 0   NOT NULL            /* 140 対応順       */
 , CONV_FUNC    VARCHAR (  500 )                                        /* 150 変換関数     */
 , F_CLM        VARCHAR ( 1000 )                                        /* 190 元項目       */
 , F_NAME_JA    VARCHAR (  200 )                                        /* 210 元名称       */
 , F_CLS_NAME   VARCHAR (   10 )                                        /* 220 元DBｸﾗｽ      */
 , F_USE_LENGTH VARCHAR (    9 )                                        /* 230 元使用桁数   */
 , F_BIKO       VARCHAR ( 2000 )                                        /* 240 元備考       */
 , DESCRIPTION  VARCHAR ( 4000 )                                        /* 250 概要説明     */
 , UNIQ         BIGINT                              NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者       */
);

CREATE SEQUENCE GF85S00 ;

CREATE TRIGGER GF85T00 FOR GF85
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GF85S00,1 );
  END;

==> openGion6.4.0.0_dev.zip: uap/webapps/gf/db/firebird/sql/install/01_TABLE/GF85S.sql <==
/****************************************************************************/
/* GF85 ( 移行DB対応明細 )                                                  */
/*                                                                          */
/* Created : 2015/11/16 16:20:12                                            */
/****************************************************************************/
CREATE TABLE GF85 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR (    1 )                    NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , TABLE_NAME   VARCHAR (   50 )                    NOT NULL            /*  30 ﾃｰﾌﾞﾙ名      */
 , CLM          VARCHAR (   30 )                    NOT NULL            /*  40 項目         */
 , SEQNO        INTEGER                 DEFAULT 0   NOT NULL            /*  50 表示順       */
 , NAME_JA      VARCHAR (  200 )                                        /*  60 名称         */
 , CLS_NAME     VARCHAR (   10 )                    NOT NULL            /*  70 DBｸﾗｽ        */
 , USE_LENGTH   VARCHAR (    9 )                                        /*  80 使用桁数     */
 , DATA_DEFAULT VARCHAR (  200 )                                        /*  90 初期値       */
 , NOT_NULL     VARCHAR (    1 )                                        /* 100 ﾉｯﾄﾇﾙ        */
 , FGCOM        VARCHAR (    1 )        DEFAULT '0' NOT NULL            /* 110 共通項目F    */
 , BIKO         VARCHAR ( 2000 )                                        /* 120 備考         */
 , NOJUN        INTEGER                 DEFAULT 0   NOT NULL            /* 130 対応順       */
 , CONV_FUNC    VARCHAR (  500 )                                        /* 140 変換関数     */
 , F_CONST      VARCHAR (  200 )                                        /* 150 元固定値     */
 , F_SYSTEM_ID  VARCHAR (   10 )                                        /* 160 元ｼｽﾃﾑID     */
 , F_TABLE_NAME VARCHAR (   50 )                                        /* 170 元ﾃｰﾌﾞﾙ名    */
 , F_CLM        VARCHAR (   30 )                                        /* 180 元項目       */
 , F_SEQNO      INTEGER                 DEFAULT 0   NOT NULL            /* 190 元表示順     */
 , F_NAME_JA    VARCHAR (  200 )                                        /* 200 元名称       */
 , F_CLS_NAME   VARCHAR (   10 )                                        /* 210 元DBｸﾗｽ      */
 , F_USE_LENGTH VARCHAR (    9 )                                        /* 220 元使用桁数   */
 , F_BIKO       VARCHAR ( 2000 )                                        /* 230 元備考       */
 , DESCRIPTION  VARCHAR ( 4000 )                                        /* 240 概要説明     */
 , UNIQ         BIGINT                              NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者       */
);

CREATE SEQUENCE GF85S00 ;

CREATE TRIGGER GF85T00 FOR GF85
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GF85S00,1 );
  END;
